@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2018 Scott Shawcroft for Adafruit Industries
 #
-# Copyright (c) 2018 Scott Shawcroft for Adafruit Industries LLC
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_imageload.bmp`
 ====================================================
@@ -37,21 +20,21 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_ImageLoad.git"
 def load(file, *, bitmap=None, palette=None):
     """Loads a bmp image from the open ``file``.
 
-       Returns tuple of bitmap object and palette object.
+    Returns tuple of bitmap object and palette object.
 
-       :param object bitmap: Type to store bitmap data. Must have API similar to `displayio.Bitmap`.
-         Will be skipped if None
-       :param object palette: Type to store the palette. Must have API similar to
-         `displayio.Palette`. Will be skipped if None"""
+    :param object bitmap: Type to store bitmap data. Must have API similar to `displayio.Bitmap`.
+      Will be skipped if None
+    :param object palette: Type to store the palette. Must have API similar to
+      `displayio.Palette`. Will be skipped if None"""
     file.seek(10)
     data_start = int.from_bytes(file.read(4), "little")
     # f.seek(14)
     # bmp_header_length = int.from_bytes(file.read(4), 'little')
     # print(bmp_header_length)
     file.seek(0x12)  # Width of the bitmap in pixels
-    width = int.from_bytes(file.read(4), "little")
+    _width = int.from_bytes(file.read(4), "little")
     try:
-        height = int.from_bytes(file.read(4), "little")
+        _height = int.from_bytes(file.read(4), "little")
     except OverflowError as error:
         raise NotImplementedError(
             "Negative height BMP files are not supported on builds without longint"
@@ -75,8 +58,8 @@ def load(file, *, bitmap=None, palette=None):
 
     return indexed.load(
         file,
-        width,
-        height,
+        _width,
+        _height,
         data_start,
         colors,
         color_depth,
